# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Imports

Package implementing a checker for import statements.

### Modules

ImportNode | Module implementing a class representing an import or import from node.
ImportsChecker | Module implementing a checker for import statements.
ImportsEnums | Module implementing some enums for the import order checker.
LocalImportVisitor | Module implementing a node visitor for checking local import statements.
translations | Module implementing message translations for the code style plugin messages (import statements part).